@@ -3,7 +3,7 @@
 ;; Copyright (C) 2023 Free Software Foundation, Inc.
 
 ;; Author: Thomas Fitzsimmons <fitzsim@fitzsim.org>
-;; Version: 0.9.0
+;; Version: 0.9.3
 ;; Package-Requires: ((emacs "26.1"))
 
 ;; This program is free software; you can redistribute it and/or modify
@@ -147,7 +147,7 @@ ARGUMENTS will be used for FORMAT, like `messages'."
   (let ((quirk
          (with-temp-buffer
            (insert-file-contents (expand-file-name
-                                  "wtfjs/README.md"
+                                  "wtfjs.README.md"
                                   fjrepl--directory))
            (goto-char (point-min))
            (let* ((regexp "^```js\n")
@@ -158,7 +158,7 @@ ARGUMENTS will be used for FORMAT, like `messages'."
                (beginning-of-line)
                (backward-char)
                (buffer-substring start (point)))))))
-    (let ((minibuffer-message-timeout 4))
+    (let ((minibuffer-message-timeout 7))
       (minibuffer-message
        (with-temp-buffer (js-mode)
                          (insert "// JavaScript quirk of the day:\n")
@@ -206,10 +206,7 @@ ARGUMENTS will be used for FORMAT, like `messages'."
               (lambda ()
                 (let ((network (get-process "firefox-javascript-repl")))
                   (when network (kill-process network)))))
-    ;; FIXME: Remove this ignore-errors after confirmation that GNU
-    ;; ELPA will check out the wtfjs submodule.
-    (ignore-errors
-      (fjrepl--show-quirk))))
+    (fjrepl--show-quirk)))
 
 (defun fjrepl--create-profile-directory ()
   "Create a profile directory."
@@ -324,7 +321,6 @@ the FRDP connection to Firefox."
 
 (defun fjrepl--stop ()
   "Stop the Firefox process started by `firefox-javascript-repl'."
-  (interactive)
   (kill-process "firefox-javascript-repl"))
 
 (defun fjrepl--ensure-count (message)
@@ -438,6 +434,7 @@ the FRDP connection to Firefox."
                      (if nextp 'fjrepl--handle-tab 'fjrepl--handle-first)
                      name buffer network)))))
 
+;;;###autoload
 (defun firefox-javascript-repl ()
   "Run a new instance of Firefox in a new profile.
 Set about:config values `devtools.debugger.remote-enabled' to
